# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OCI


class _Devops(_OCI):
    _type = "devops"
    _icon_dir = "resources/oci/devops"


class Apiservice(_Devops):
    _icon = "apiservice.png"


class Resourcemgmt(_Devops):
    _icon = "resourcemgmt.png"


# Aliases
